"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.getDomain = exports.getEIP712Domain = exports.getSignedDataStruct = void 0;
/**
 * This returns a SignedDataStruct.
 * @param AuthSignature
 * @param domain
 * @param nonce
 * @private
 * @returns The structured data
 */
function getSignedDataStruct(AuthSignature, domain, nonce) {
    return {
        types: {
            EIP712Domain: getEIP712Domain(),
            AuthSignature: AuthSignature,
        },
        domain: domain,
        primaryType: "AuthSignature",
        message: {
            value: "Authentication message: " + nonce
        },
    };
}
exports.getSignedDataStruct = getSignedDataStruct;
/**
 * Composes the domain definition object.
 * @private
 * @returns Domain definition object
 */
function getEIP712Domain() {
    return [
        { name: "name", type: "string" },
        { name: "version", type: "string" },
        { name: "chainId", type: "uint256" },
        { name: "verifyingContract", type: "address" },
    ];
}
exports.getEIP712Domain = getEIP712Domain;
/**
 * Compose the domain object.
 * @param chainId
 * @private
 * @returns Domain object
 */
function getDomain(chainId) {
    return {
        name: "Boson Protocol",
        version: "1",
        chainId: chainId,
        verifyingContract: "0xCcCCccccCCCCcCCCCCCcCcCccCcCCCcCcccccccC",
    };
}
exports.getDomain = getDomain;
//# sourceMappingURL=message.js.map