import { expect } from "chai";
import { ethers } from "ethers";
import { ClientLibrary } from "../../src";
import { Web3Provider } from "../../src/web3/web3.provider";
import { TestHelperTypes } from "../helpers/types";

let clientLibrary: ClientLibrary;
let web3Provider: Web3Provider;
let wallet: ethers.Wallet;

before(function() {
    clientLibrary = new ClientLibrary("https://psyched-hook-280010.oa.r.appspot.com");
    web3Provider = TestHelperTypes.provider();
    wallet = TestHelperTypes.wallet();
});

describe("User tests - Integration", function() {
    it("Authenticate user (request JWT token by authenticating valid user) - expect pass", async () => {
        const account: string = wallet.address;

        const jwtToken: string = await clientLibrary.authenticateUser(account, web3Provider);

        expect(jwtToken).not.to.be.undefined;
    });

    it("Authenticate user (request JWT token by authenticating invalid user) - expect failure", async () => {
        const invalidAccount: string = "0x4867d7AcD1EC5f210E9590666498e0cC5D13a84c"; // fake address

        let jwtToken = undefined;
        try {
            jwtToken = await clientLibrary.authenticateUser(invalidAccount, web3Provider);
        } catch (e) {}

        expect(jwtToken).to.be.undefined;
    });
});